"use server";

import { auth } from "@/auth";
import { prisma } from "@/prisma/prismaClient";
import { isEmailVerified } from "@/util/isEmailVerified";
import { redirect } from "next/navigation";

export const createSchema = async (form: FormData) => {
  const name = form.get("name")?.toString();
  const gsId = form.get("gsId")?.toString();

  const session = await auth();

  if (!name || !gsId || !session?.user?.id || !isEmailVerified(session.user.id))
    return;

  const { id } = await prisma.schema.create({
    data: {
      name,
      schema: "{}",
      types: "{}",
      version: 0,
      gameSystemId: gsId,
      authorId: session.user.id,
    },
    select: { id: true },
  });
  redirect(`/game-systems/${gsId}/schema/${id}`);
};
